stm32-metapac

Crates

git

Versions

stm32h503kb

Flavors

Tgttdr

Struct Tgttdr 

#[repr(transparent)]
pub struct Tgttdr(pub u32);
I3C target transmit configuration register.

Tuple Fields

0: u32

Implementations



impl Tgttdr

pub const fn tgttdcnt(&self) -> u16

transmit data counter, in bytes (when I3C is configured as target) This field must be written by software in the same access when is asserted PRELOAD, in order to define the number of bytes to preload and to transmit. This field is updated by hardware and reports, when read, the remaining number of bytes to be loaded into the TX-FIFO.

pub const fn set_tgttdcnt(&mut self, val: u16)

transmit data counter, in bytes (when I3C is configured as target) This field must be written by software in the same access when is asserted PRELOAD, in order to define the number of bytes to preload and to transmit. This field is updated by hardware and reports, when read, the remaining number of bytes to be loaded into the TX-FIFO.

pub const fn preload(&self) -> bool

preload of the TX-FIFO (when I3C is configured as target) This bit must be written and asserted by software in the same access when is written and defined the number of bytes to preload into the TX-FIFO and to transmit. This bit is cleared by hardware when all the data bytes to transmit are loaded into the TX-FIFO.

pub const fn set_preload(&mut self, val: bool)

preload of the TX-FIFO (when I3C is configured as target) This bit must be written and asserted by software in the same access when is written and defined the number of bytes to preload into the TX-FIFO and to transmit. This bit is cleared by hardware when all the data bytes to transmit are loaded into the TX-FIFO.